@@ -109,7 +109,7 @@ class MetaLens:
         if (
             results.last is not None
             and self.pixelization is not None
-            and not self.pixelizaition_is_model
+            and not self.pixelization_is_model
         ):
             if self.pixelization.__class__ is results.last.pixelization.__class__:
                 if hasattr(results.last, "hyper_combined"):
