@@ -212,6 +212,7 @@ class HyperSetup(setup.PipelineSetup):
         hyper_galaxies_search=None,
         inversion_search=None,
         hyper_combined_search=None,
+        evidence_tolerance=None,
     ):
         """The setup of a pipeline, which controls how PyAutoLens template pipelines runs, for example controlling
         assumptions about the lens's light profile bulge-disk model or if shear is included in the mass model.
@@ -245,6 +246,7 @@ class HyperSetup(setup.PipelineSetup):
             hyper_galaxies_search=hyper_galaxies_search,
             inversion_search=inversion_search,
             hyper_combined_search=hyper_combined_search,
+            evidence_tolerance=evidence_tolerance,
         )
 
         self.hyper_fixed_after_source = hyper_fixed_after_source
@@ -297,24 +299,24 @@ class SourceSetup(setup.PipelineSetup):
         self,
         pixelization=None,
         regularization=None,
+        inversion_pixels_fixed=None,
         no_shear=False,
         lens_light_centre=None,
         lens_mass_centre=None,
         align_light_mass_centre=False,
         lens_light_bulge_only=False,
         number_of_gaussians=None,
-        inversion_evidence_tolerance=None,
     ):
 
         super().__init__(
             pixelization=pixelization,
             regularization=regularization,
+            inversion_pixels_fixed=inversion_pixels_fixed,
             no_shear=no_shear,
             lens_light_centre=lens_light_centre,
             lens_mass_centre=lens_mass_centre,
             number_of_gaussians=number_of_gaussians,
             align_light_mass_centre=align_light_mass_centre,
-            inversion_evidence_tolerance=inversion_evidence_tolerance,
         )
 
         self.lens_light_bulge_only = lens_light_bulge_only
@@ -434,6 +436,11 @@ class SourceSetup(setup.PipelineSetup):
                 mean=self.lens_mass_centre[1], sigma=0.05
             )
 
+        else:
+
+            mass.centre.centre_0 = af.last[-1].model.galaxies.lens.mass.centre.centre_0
+            mass.centre.centre_1 = af.last[-1].model.galaxies.lens.mass.centre.centre_1
+
         return mass
 
     def unalign_lens_mass_centre_from_light_centre(self, mass):
@@ -444,6 +451,10 @@ class SourceSetup(setup.PipelineSetup):
 
             mass.centre = af.last[-3].model.galaxies.lens.bulge.centre
 
+        else:
+
+            mass.centre = af.last[-1].model.galaxies.lens.mass.centre
+
         return mass
 
 
