@@ -20,6 +20,10 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
         search=af.DynestyStatic(n_live_points=40, evidence_tolerance=10.0),
     )
 
+    phase1 = phase1.extend_with_multiple_hyper_phases(
+        setup=al.PipelineSetup(), include_inversion=False
+    )
+
     phase2 = al.PhaseImaging(
         phase_name="phase_2",
         folders=folders,
@@ -33,10 +37,12 @@ def make_pipeline(name, folders, search=af.DynestyStatic()):
                 regularization=al.reg.AdaptiveBrightness,
             ),
         ),
-        search=af.DynestyStatic(n_live_points=40, evidence_tolerance=10.0),
+        search=af.DynestyStatic(n_live_points=40),
     )
 
-    phase2 = phase2.extend_with_stochastic_phase(stochastic_search=None)
+    phase2 = phase2.extend_with_stochastic_phase(
+        stochastic_search=af.DynestyStatic(n_live_points=40, evidence_tolerance=10000.0)
+    )
 
     return al.PipelineDataset(name, phase1, phase2)
 
