@@ -6,7 +6,7 @@ import autolens as al
 # Lets take another look at the rectangular grid, and think about its weakness.
 
 # Lets quickly remind ourselves of the image, and the 3.0" circular mask we'll use to mask it.
-imaging = simulate_util.load_test_imaging(
+imaging = instrument_util.load_test_imaging(
     data_name="lens_light_dev_vaucouleurs", instrument="vro"
 )
 mask = al.Mask.circular(
