@@ -2,7 +2,7 @@ import os
 
 import autofit as af
 import autolens as al
-from test_autolens.simulate.imaging import simulate_util
+from test_autolens.simulate.imaging import instrument_util
 
 # Get the relative path to the config files and output folder in our autolens_workspace.
 test_path = "{}/../".format(os.path.dirname(os.path.realpath(__file__)))
@@ -26,7 +26,7 @@ outer_radius = 3.0
 # more precise interpolation of the sub-grid deflection angles.
 pixel_scales_interp = 0.2
 
-imaging = simulate_util.load_test_imaging(
+imaging = instrument_util.load_test_imaging(
     data_name=data_name, instrument=instrument, psf_shape_2d=(21, 21)
 )
 
