@@ -2,7 +2,7 @@ import time
 
 import autolens as al
 import numpy as np
-from test_autolens.simulate.imaging import simulate_util
+from test_autolens.simulators.imaging import instrument_util
 
 repeats = 10
 
@@ -36,7 +36,7 @@ source_galaxy = al.Galaxy(
 
 for instrument in ["vro", "euclid", "hst", "hst_up"]:  # , 'ao']:
 
-    imaging = simulate_util.load_test_imaging(
+    imaging = instrument_util.load_test_imaging(
         data_name="lens_sie__source_smooth",
         instrument=instrument,
         psf_shape_2d=psf_shape_2d,
